@@ -1,15 +1,17 @@
 package create
 
 import (
+	"context"
 	"fmt"
 
 	"github.com/spf13/cobra"
 
+	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/meta"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/cli-runtime/pkg/genericclioptions"
 	kcmdutil "k8s.io/kubectl/pkg/cmd/util"
 	"k8s.io/kubectl/pkg/util/templates"
-	kapi "k8s.io/kubernetes/pkg/apis/core"
 
 	routev1 "github.com/openshift/api/route/v1"
 	"github.com/openshift/oc/pkg/cli/create/route"
@@ -127,8 +129,8 @@ func (o *CreateEdgeRouteOptions) Run() error {
 		route.Spec.TLS.InsecureEdgeTerminationPolicy = routev1.InsecureEdgeTerminationPolicyType(o.InsecurePolicy)
 	}
 
-	if !o.CreateRouteSubcommandOptions.DryRun {
-		route, err = o.CreateRouteSubcommandOptions.Client.Routes(o.CreateRouteSubcommandOptions.Namespace).Create(route)
+	if o.CreateRouteSubcommandOptions.DryRunStrategy != kcmdutil.DryRunClient {
+		route, err = o.CreateRouteSubcommandOptions.Client.Routes(o.CreateRouteSubcommandOptions.Namespace).Create(context.TODO(), route, metav1.CreateOptions{})
 		if err != nil {
 			return err
 		}
@@ -141,11 +143,11 @@ func resolveServiceName(mapper meta.RESTMapper, resource string) (string, error)
 	if len(resource) == 0 {
 		return "", fmt.Errorf("you need to provide a service name via --service")
 	}
-	rType, name, err := cmdutil.ResolveResource(kapi.Resource("services"), resource, mapper)
+	rType, name, err := cmdutil.ResolveResource(corev1.Resource("services"), resource, mapper)
 	if err != nil {
 		return "", err
 	}
-	if rType != kapi.Resource("services") {
+	if rType != corev1.Resource("services") {
 		return "", fmt.Errorf("cannot expose %v as routes", rType)
 	}
 	return name, nil
